pub struct ConcurrentSlabMetrics {
pub slab: String,
pub length: usize,
pub capacity: usize,
pub memory_usage: usize,
pub content_memory_usage: usize,
pub free_slots_length: usize,
pub free_slots_capacity: usize,
}Fields
slab: Stringlength: usizecapacity: usizememory_usage: usizeApproximate memory usage of the content of the slab Vec.
content_memory_usage: usizeApproximate memory usage of the total content of elements of type T
the slab slots point to via Arc<T>. This does not
include any additional memory allocated by individual T elements,
just the raw size of each T.
free_slots_length: usizefree_slots_capacity: usizeTrait Implementations
Sourceimpl Clone for ConcurrentSlabMetrics
impl Clone for ConcurrentSlabMetrics
Sourcefn clone(&self) -> ConcurrentSlabMetrics
fn clone(&self) -> ConcurrentSlabMetrics
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ConcurrentSlabMetrics
impl Debug for ConcurrentSlabMetrics
Sourceimpl<'de> Deserialize<'de> for ConcurrentSlabMetrics
impl<'de> Deserialize<'de> for ConcurrentSlabMetrics
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more